schemas
==========

Schemas provide the ruleset for a topology file. The examples here are based
upon iterations over time. However, a completely different schema could
accomplish the task of provisioning resources.
